"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.spark.v1.maintenance_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Health:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Health.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HEALTH_UNKNOWN: _Health.ValueType  # 0
    """Cluster is in unknown state (we have no data)."""
    ALIVE: _Health.ValueType  # 1
    """Cluster is alive and well."""
    DEAD: _Health.ValueType  # 2
    """Cluster is inoperable (it cannot perform any of its essential functions)."""
    DEGRADED: _Health.ValueType  # 3
    """Cluster is partially alive (it can perform some of its essential functions)."""

class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...

HEALTH_UNKNOWN: Health.ValueType  # 0
"""Cluster is in unknown state (we have no data)."""
ALIVE: Health.ValueType  # 1
"""Cluster is alive and well."""
DEAD: Health.ValueType  # 2
"""Cluster is inoperable (it cannot perform any of its essential functions)."""
DEGRADED: Health.ValueType  # 3
"""Cluster is partially alive (it can perform some of its essential functions)."""
global___Health = Health

@typing.final
class Cluster(google.protobuf.message.Message):
    """Spark cluster."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNKNOWN: Cluster._Status.ValueType  # 0
        """Cluster status is unknown"""
        CREATING: Cluster._Status.ValueType  # 1
        """Cluster is being created"""
        RUNNING: Cluster._Status.ValueType  # 2
        """Cluster is running normally."""
        UPDATING: Cluster._Status.ValueType  # 3
        """Cluster is being updated."""
        ERROR: Cluster._Status.ValueType  # 4
        """Cluster encountered a problem and cannot operate."""
        STOPPING: Cluster._Status.ValueType  # 5
        """Cluster is stopping."""
        STOPPED: Cluster._Status.ValueType  # 6
        """Cluster is stopped."""
        STARTING: Cluster._Status.ValueType  # 7
        """Cluster is starting."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNKNOWN: Cluster.Status.ValueType  # 0
    """Cluster status is unknown"""
    CREATING: Cluster.Status.ValueType  # 1
    """Cluster is being created"""
    RUNNING: Cluster.Status.ValueType  # 2
    """Cluster is running normally."""
    UPDATING: Cluster.Status.ValueType  # 3
    """Cluster is being updated."""
    ERROR: Cluster.Status.ValueType  # 4
    """Cluster encountered a problem and cannot operate."""
    STOPPING: Cluster.Status.ValueType  # 5
    """Cluster is stopping."""
    STOPPED: Cluster.Status.ValueType  # 6
    """Cluster is stopped."""
    STARTING: Cluster.Status.ValueType  # 7
    """Cluster is starting."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    LINKS_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    PLANNED_OPERATION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique ID of the Spark cluster.
    This ID is assigned by Cloud in the process of creating a Spark cluster.
    """
    folder_id: builtins.str
    """ID of the folder that the Spark cluster belongs to."""
    name: builtins.str
    """Name of the Spark cluster.
    The name is unique within the folder. 1-64 characters long.
    """
    description: builtins.str
    """Description of the Spark cluster. 0-256 characters long."""
    status: global___Cluster.Status.ValueType
    """Cluster status."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster"""
    service_account_id: builtins.str
    """Service account that will be used to access a YC resources"""
    health: global___Health.ValueType
    """Aggregated cluster health."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when the Spark cluster was created."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def config(self) -> global___ClusterConfig:
        """Configuration of the Spark cluster."""

    @property
    def network(self) -> global___NetworkConfig: ...
    @property
    def logging(self) -> global___LoggingConfig:
        """Cloud logging configuration."""

    @property
    def links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UILink]:
        """UI URLs"""

    @property
    def maintenance_window(self) -> yandex.cloud.spark.v1.maintenance_pb2.MaintenanceWindow:
        """Window of maintenance operations."""

    @property
    def planned_operation(self) -> yandex.cloud.spark.v1.maintenance_pb2.MaintenanceOperation:
        """Maintenance operation planned at nearest maintenance_window."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        config: global___ClusterConfig | None = ...,
        status: global___Cluster.Status.ValueType = ...,
        network: global___NetworkConfig | None = ...,
        deletion_protection: builtins.bool = ...,
        service_account_id: builtins.str = ...,
        logging: global___LoggingConfig | None = ...,
        health: global___Health.ValueType = ...,
        links: collections.abc.Iterable[global___UILink] | None = ...,
        maintenance_window: yandex.cloud.spark.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        planned_operation: yandex.cloud.spark.v1.maintenance_pb2.MaintenanceOperation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "logging", b"logging", "maintenance_window", b"maintenance_window", "network", b"network", "planned_operation", b"planned_operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "health", b"health", "id", b"id", "labels", b"labels", "links", b"links", "logging", b"logging", "maintenance_window", b"maintenance_window", "name", b"name", "network", b"network", "planned_operation", b"planned_operation", "service_account_id", b"service_account_id", "status", b"status"]) -> None: ...

global___Cluster = Cluster

@typing.final
class ClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_POOLS_FIELD_NUMBER: builtins.int
    HISTORY_SERVER_FIELD_NUMBER: builtins.int
    DEPENDENCIES_FIELD_NUMBER: builtins.int
    METASTORE_FIELD_NUMBER: builtins.int
    @property
    def resource_pools(self) -> global___ResourcePools: ...
    @property
    def history_server(self) -> global___HistoryServerConfig:
        """Configuration for HistoryServer"""

    @property
    def dependencies(self) -> global___Dependencies:
        """Container custom environment dependencies"""

    @property
    def metastore(self) -> global___Metastore:
        """Metastore Cluster"""

    def __init__(
        self,
        *,
        resource_pools: global___ResourcePools | None = ...,
        history_server: global___HistoryServerConfig | None = ...,
        dependencies: global___Dependencies | None = ...,
        metastore: global___Metastore | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["dependencies", b"dependencies", "history_server", b"history_server", "metastore", b"metastore", "resource_pools", b"resource_pools"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dependencies", b"dependencies", "history_server", b"history_server", "metastore", b"metastore", "resource_pools", b"resource_pools"]) -> None: ...

global___ClusterConfig = ClusterConfig

@typing.final
class UpdateClusterConfigSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_POOLS_FIELD_NUMBER: builtins.int
    HISTORY_SERVER_FIELD_NUMBER: builtins.int
    DEPENDENCIES_FIELD_NUMBER: builtins.int
    METASTORE_FIELD_NUMBER: builtins.int
    @property
    def resource_pools(self) -> global___ResourcePools: ...
    @property
    def history_server(self) -> global___HistoryServerConfig:
        """Configuration for HistoryServer"""

    @property
    def dependencies(self) -> global___Dependencies:
        """Container custom environment dependencies"""

    @property
    def metastore(self) -> global___Metastore:
        """Metastore Cluster"""

    def __init__(
        self,
        *,
        resource_pools: global___ResourcePools | None = ...,
        history_server: global___HistoryServerConfig | None = ...,
        dependencies: global___Dependencies | None = ...,
        metastore: global___Metastore | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["dependencies", b"dependencies", "history_server", b"history_server", "metastore", b"metastore", "resource_pools", b"resource_pools"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dependencies", b"dependencies", "history_server", b"history_server", "metastore", b"metastore", "resource_pools", b"resource_pools"]) -> None: ...

global___UpdateClusterConfigSpec = UpdateClusterConfigSpec

@typing.final
class HistoryServerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["enabled", b"enabled"]) -> None: ...

global___HistoryServerConfig = HistoryServerConfig

@typing.final
class NetworkConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_IDS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of VPC network subnets where instances of the cluster are attached."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups"""

    def __init__(
        self,
        *,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_group_ids", b"security_group_ids", "subnet_ids", b"subnet_ids"]) -> None: ...

global___NetworkConfig = NetworkConfig

@typing.final
class UpdateNetworkConfigSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups."""

    def __init__(
        self,
        *,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_group_ids", b"security_group_ids"]) -> None: ...

global___UpdateNetworkConfigSpec = UpdateNetworkConfigSpec

@typing.final
class ResourcePools(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DRIVER_FIELD_NUMBER: builtins.int
    EXECUTOR_FIELD_NUMBER: builtins.int
    @property
    def driver(self) -> global___ResourcePool: ...
    @property
    def executor(self) -> global___ResourcePool: ...
    def __init__(
        self,
        *,
        driver: global___ResourcePool | None = ...,
        executor: global___ResourcePool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["driver", b"driver", "executor", b"executor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["driver", b"driver", "executor", b"executor"]) -> None: ...

global___ResourcePools = ResourcePools

@typing.final
class ResourcePool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    SCALE_POLICY_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the preset for computational resources allocated to a instance (e.g., CPU, memory, etc.)."""
    @property
    def scale_policy(self) -> global___ScalePolicy: ...
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
        scale_policy: global___ScalePolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["scale_policy", b"scale_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource_preset_id", b"resource_preset_id", "scale_policy", b"scale_policy"]) -> None: ...

global___ResourcePool = ResourcePool

@typing.final
class ScalePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class FixedScale(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SIZE_FIELD_NUMBER: builtins.int
        size: builtins.int
        def __init__(
            self,
            *,
            size: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["size", b"size"]) -> None: ...

    @typing.final
    class AutoScale(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MIN_SIZE_FIELD_NUMBER: builtins.int
        MAX_SIZE_FIELD_NUMBER: builtins.int
        min_size: builtins.int
        max_size: builtins.int
        def __init__(
            self,
            *,
            min_size: builtins.int = ...,
            max_size: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["max_size", b"max_size", "min_size", b"min_size"]) -> None: ...

    FIXED_SCALE_FIELD_NUMBER: builtins.int
    AUTO_SCALE_FIELD_NUMBER: builtins.int
    @property
    def fixed_scale(self) -> global___ScalePolicy.FixedScale: ...
    @property
    def auto_scale(self) -> global___ScalePolicy.AutoScale: ...
    def __init__(
        self,
        *,
        fixed_scale: global___ScalePolicy.FixedScale | None = ...,
        auto_scale: global___ScalePolicy.AutoScale | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auto_scale", b"auto_scale", "fixed_scale", b"fixed_scale", "scale_type", b"scale_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_scale", b"auto_scale", "fixed_scale", b"fixed_scale", "scale_type", b"scale_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["scale_type", b"scale_type"]) -> typing.Literal["fixed_scale", "auto_scale"] | None: ...

global___ScalePolicy = ScalePolicy

@typing.final
class Dependencies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIP_PACKAGES_FIELD_NUMBER: builtins.int
    DEB_PACKAGES_FIELD_NUMBER: builtins.int
    @property
    def pip_packages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def deb_packages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        pip_packages: collections.abc.Iterable[builtins.str] | None = ...,
        deb_packages: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deb_packages", b"deb_packages", "pip_packages", b"pip_packages"]) -> None: ...

global___Dependencies = Dependencies

@typing.final
class Metastore(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___Metastore = Metastore

@typing.final
class LoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    folder_id: builtins.str
    log_group_id: builtins.str
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        folder_id: builtins.str = ...,
        log_group_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination", b"destination", "enabled", b"enabled", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["folder_id", "log_group_id"] | None: ...

global___LoggingConfig = LoggingConfig

@typing.final
class UILink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    name: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "url", b"url"]) -> None: ...

global___UILink = UILink



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.containerregistry.v1.blob_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Image(google.protobuf.message.Message):
    """An Image resource. For more information, see [Docker image](/docs/container-registry/concepts/docker-image)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DIGEST_FIELD_NUMBER: builtins.int
    COMPRESSED_SIZE_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    LAYERS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Output only. ID of the Docker image."""
    name: builtins.str
    """Name of the Docker image.
    The name is unique within the registry.
    """
    digest: builtins.str
    """Content-addressable identifier of the Docker image."""
    compressed_size: builtins.int
    """Compressed size of the Docker image, specified in bytes."""
    @property
    def config(self) -> yandex.cloud.containerregistry.v1.blob_pb2.Blob:
        """Configuration of the Docker image."""

    @property
    def layers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.containerregistry.v1.blob_pb2.Blob]:
        """Layers of the Docker image."""

    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Tags of the Docker image.

        Each tag is unique within the repository.
        """

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Output only. Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        digest: builtins.str = ...,
        compressed_size: builtins.int = ...,
        config: yandex.cloud.containerregistry.v1.blob_pb2.Blob | None = ...,
        layers: collections.abc.Iterable[yandex.cloud.containerregistry.v1.blob_pb2.Blob] | None = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["compressed_size", b"compressed_size", "config", b"config", "created_at", b"created_at", "digest", b"digest", "id", b"id", "layers", b"layers", "name", b"name", "tags", b"tags"]) -> None: ...

global___Image = Image



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/logging/v1/sink_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/logging/v1/sink_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.logging.v1 import sink_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_sink__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/logging/v1/sink_service.proto\x12\x17yandex.cloud.logging.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/logging/v1/sink.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"/\n\x0eGetSinkRequest\x12\x1d\n\x07sink_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"\x87\x01\n\x10ListSinksRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x11\n\tpage_size\x18\x03 \x01(\x03\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x02\x10\x03\"Z\n\x11ListSinksResponse\x12,\n\x05sinks\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.logging.v1.Sink\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xd0\x03\n\x11\x43reateSinkRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x83\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x36.yandex.cloud.logging.v1.CreateSinkRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12$\n\x12service_account_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=64\x12\x30\n\x03yds\x18\x06 \x01(\x0b\x32!.yandex.cloud.logging.v1.Sink.YdsH\x00\x12.\n\x02s3\x18\x07 \x01(\x0b\x32 .yandex.cloud.logging.v1.Sink.S3H\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\x04sink\x12\x04\xc0\xc1\x31\x01\"%\n\x12\x43reateSinkMetadata\x12\x0f\n\x07sink_id\x18\x01 \x01(\t\"\xff\x03\n\x11UpdateSinkRequest\x12\x1d\n\x07sink_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x83\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x36.yandex.cloud.logging.v1.UpdateSinkRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12$\n\x12service_account_id\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=64\x12\x30\n\x03yds\x18\x07 \x01(\x0b\x32!.yandex.cloud.logging.v1.Sink.YdsH\x00\x12.\n\x02s3\x18\x08 \x01(\x0b\x32 .yandex.cloud.logging.v1.Sink.S3H\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\x04sink\x12\x04\xc0\xc1\x31\x01\"%\n\x12UpdateSinkMetadata\x12\x0f\n\x07sink_id\x18\x01 \x01(\t\"2\n\x11\x44\x65leteSinkRequest\x12\x1d\n\x07sink_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"%\n\x12\x44\x65leteSinkMetadata\x12\x0f\n\x07sink_id\x18\x01 \x01(\t\"\x94\x01\n\x19ListSinkOperationsRequest\x12\x1d\n\x07sink_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"l\n\x1aListSinkOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x91\x0c\n\x0bSinkService\x12r\n\x03Get\x12\'.yandex.cloud.logging.v1.GetSinkRequest\x1a\x1d.yandex.cloud.logging.v1.Sink\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/logging/v1/sinks/{sink_id}\x12x\n\x04List\x12).yandex.cloud.logging.v1.ListSinksRequest\x1a*.yandex.cloud.logging.v1.ListSinksResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/logging/v1/sinks\x12\x93\x01\n\x06\x43reate\x12*.yandex.cloud.logging.v1.CreateSinkRequest\x1a!.yandex.cloud.operation.Operation\":\xb2\xd2*\x1a\n\x12\x43reateSinkMetadata\x12\x04Sink\x82\xd3\xe4\x93\x02\x16\"\x11/logging/v1/sinks:\x01*\x12\x9d\x01\n\x06Update\x12*.yandex.cloud.logging.v1.UpdateSinkRequest\x1a!.yandex.cloud.operation.Operation\"D\xb2\xd2*\x1a\n\x12UpdateSinkMetadata\x12\x04Sink\x82\xd3\xe4\x93\x02 2\x1b/logging/v1/sinks/{sink_id}:\x01*\x12\xab\x01\n\x06\x44\x65lete\x12*.yandex.cloud.logging.v1.DeleteSinkRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2*+\n\x12\x44\x65leteSinkMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1d*\x1b/logging/v1/sinks/{sink_id}\x12\xa9\x01\n\x0eListOperations\x12\x32.yandex.cloud.logging.v1.ListSinkOperationsRequest\x1a\x33.yandex.cloud.logging.v1.ListSinkOperationsResponse\".\x82\xd3\xe4\x93\x02(\x12&/logging/v1/sinks/{sink_id}/operations\x12\xb1\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/logging/v1/sinks/{resource_id}:listAccessBindings\x12\xe0\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"y\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x36\"1/logging/v1/sinks/{resource_id}:setAccessBindings:\x01*\x12\xec\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x39\x32\x34/logging/v1/sinks/{resource_id}:updateAccessBindings:\x01*Bb\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.logging.v1.sink_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging'
  _globals['_GETSINKREQUEST'].fields_by_name['sink_id']._loaded_options = None
  _globals['_GETSINKREQUEST'].fields_by_name['sink_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _globals['_LISTSINKSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTSINKSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _globals['_LISTSINKSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSINKSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTSINKSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSINKSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATESINKREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATESINKREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATESINKREQUEST'].oneofs_by_name['sink']._loaded_options = None
  _globals['_CREATESINKREQUEST'].oneofs_by_name['sink']._serialized_options = b'\300\3011\001'
  _globals['_CREATESINKREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATESINKREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _globals['_CREATESINKREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATESINKREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_CREATESINKREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATESINKREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATESINKREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATESINKREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CREATESINKREQUEST'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_CREATESINKREQUEST'].fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=64'
  _globals['_UPDATESINKREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATESINKREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATESINKREQUEST'].oneofs_by_name['sink']._loaded_options = None
  _globals['_UPDATESINKREQUEST'].oneofs_by_name['sink']._serialized_options = b'\300\3011\001'
  _globals['_UPDATESINKREQUEST'].fields_by_name['sink_id']._loaded_options = None
  _globals['_UPDATESINKREQUEST'].fields_by_name['sink_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _globals['_UPDATESINKREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATESINKREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_UPDATESINKREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATESINKREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATESINKREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATESINKREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATESINKREQUEST'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_UPDATESINKREQUEST'].fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=64'
  _globals['_DELETESINKREQUEST'].fields_by_name['sink_id']._loaded_options = None
  _globals['_DELETESINKREQUEST'].fields_by_name['sink_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _globals['_LISTSINKOPERATIONSREQUEST'].fields_by_name['sink_id']._loaded_options = None
  _globals['_LISTSINKOPERATIONSREQUEST'].fields_by_name['sink_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _globals['_LISTSINKOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSINKOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTSINKOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSINKOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTSINKOPERATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSINKOPERATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_SINKSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_SINKSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\035\022\033/logging/v1/sinks/{sink_id}'
  _globals['_SINKSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_SINKSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\023\022\021/logging/v1/sinks'
  _globals['_SINKSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_SINKSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\032\n\022CreateSinkMetadata\022\004Sink\202\323\344\223\002\026\"\021/logging/v1/sinks:\001*'
  _globals['_SINKSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_SINKSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\032\n\022UpdateSinkMetadata\022\004Sink\202\323\344\223\002 2\033/logging/v1/sinks/{sink_id}:\001*'
  _globals['_SINKSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_SINKSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*+\n\022DeleteSinkMetadata\022\025google.protobuf.Empty\202\323\344\223\002\035*\033/logging/v1/sinks/{sink_id}'
  _globals['_SINKSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_SINKSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002(\022&/logging/v1/sinks/{sink_id}/operations'
  _globals['_SINKSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_SINKSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0024\0222/logging/v1/sinks/{resource_id}:listAccessBindings'
  _globals['_SINKSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_SINKSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\0026\"1/logging/v1/sinks/{resource_id}:setAccessBindings:\001*'
  _globals['_SINKSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_SINKSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002924/logging/v1/sinks/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETSINKREQUEST']._serialized_start=310
  _globals['_GETSINKREQUEST']._serialized_end=357
  _globals['_LISTSINKSREQUEST']._serialized_start=360
  _globals['_LISTSINKSREQUEST']._serialized_end=495
  _globals['_LISTSINKSRESPONSE']._serialized_start=497
  _globals['_LISTSINKSRESPONSE']._serialized_end=587
  _globals['_CREATESINKREQUEST']._serialized_start=590
  _globals['_CREATESINKREQUEST']._serialized_end=1054
  _globals['_CREATESINKREQUEST_LABELSENTRY']._serialized_start=995
  _globals['_CREATESINKREQUEST_LABELSENTRY']._serialized_end=1040
  _globals['_CREATESINKMETADATA']._serialized_start=1056
  _globals['_CREATESINKMETADATA']._serialized_end=1093
  _globals['_UPDATESINKREQUEST']._serialized_start=1096
  _globals['_UPDATESINKREQUEST']._serialized_end=1607
  _globals['_UPDATESINKREQUEST_LABELSENTRY']._serialized_start=995
  _globals['_UPDATESINKREQUEST_LABELSENTRY']._serialized_end=1040
  _globals['_UPDATESINKMETADATA']._serialized_start=1609
  _globals['_UPDATESINKMETADATA']._serialized_end=1646
  _globals['_DELETESINKREQUEST']._serialized_start=1648
  _globals['_DELETESINKREQUEST']._serialized_end=1698
  _globals['_DELETESINKMETADATA']._serialized_start=1700
  _globals['_DELETESINKMETADATA']._serialized_end=1737
  _globals['_LISTSINKOPERATIONSREQUEST']._serialized_start=1740
  _globals['_LISTSINKOPERATIONSREQUEST']._serialized_end=1888
  _globals['_LISTSINKOPERATIONSRESPONSE']._serialized_start=1890
  _globals['_LISTSINKOPERATIONSRESPONSE']._serialized_end=1998
  _globals['_SINKSERVICE']._serialized_start=2001
  _globals['_SINKSERVICE']._serialized_end=3554
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cdn/v1/origin_group_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cdn/v1/origin_group_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.cdn.v1 import origin_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2
from yandex.cloud.cdn.v1 import origin_group_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/cdn/v1/origin_group_service.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/cdn/v1/origin.proto\x1a&yandex/cloud/cdn/v1/origin_group.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"Y\n\x15GetOriginGroupRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\x0forigin_group_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"x\n\x17ListOriginGroupsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"l\n\x18ListOriginGroupsResponse\x12\x37\n\rorigin_groups\x18\x01 \x03(\x0b\x32 .yandex.cloud.cdn.v1.OriginGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc2\x01\n\x18\x43reateOriginGroupRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04name\x18\x02 \x01(\t\x12,\n\x08use_next\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x07origins\x18\x04 \x03(\x0b\x32!.yandex.cloud.cdn.v1.OriginParams\x12\x15\n\rprovider_type\x18\x05 \x01(\t\"<\n\x19\x43reateOriginGroupMetadata\x12\x1f\n\x0forigin_group_id\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"\xf0\x01\n\x18UpdateOriginGroupRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\x0forigin_group_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x30\n\ngroup_name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x08use_next\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x07origins\x18\x05 \x03(\x0b\x32!.yandex.cloud.cdn.v1.OriginParams\"<\n\x19UpdateOriginGroupMetadata\x12\x1f\n\x0forigin_group_id\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"\\\n\x18\x44\x65leteOriginGroupRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\x0forigin_group_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"<\n\x19\x44\x65leteOriginGroupMetadata\x12\x1f\n\x0forigin_group_id\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>02\xb5\x06\n\x12OriginGroupService\x12\x83\x01\n\x03Get\x12*.yandex.cloud.cdn.v1.GetOriginGroupRequest\x1a .yandex.cloud.cdn.v1.OriginGroup\".\x82\xd3\xe4\x93\x02(\x12&/cdn/v1/originGroups/{origin_group_id}\x12\x81\x01\n\x04List\x12,.yandex.cloud.cdn.v1.ListOriginGroupsRequest\x1a-.yandex.cloud.cdn.v1.ListOriginGroupsResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/cdn/v1/originGroups\x12\xa7\x01\n\x06\x43reate\x12-.yandex.cloud.cdn.v1.CreateOriginGroupRequest\x1a!.yandex.cloud.operation.Operation\"K\xb2\xd2*(\n\x19\x43reateOriginGroupMetadata\x12\x0bOriginGroup\x82\xd3\xe4\x93\x02\x19\"\x14/cdn/v1/originGroups:\x01*\x12\xa7\x01\n\x06Update\x12-.yandex.cloud.cdn.v1.UpdateOriginGroupRequest\x1a!.yandex.cloud.operation.Operation\"K\xb2\xd2*(\n\x19UpdateOriginGroupMetadata\x12\x0bOriginGroup\x82\xd3\xe4\x93\x02\x19\x32\x14/cdn/v1/originGroups:\x01*\x12\xc0\x01\n\x06\x44\x65lete\x12-.yandex.cloud.cdn.v1.DeleteOriginGroupRequest\x1a!.yandex.cloud.operation.Operation\"d\xb2\xd2*2\n\x19\x44\x65leteOriginGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02(*&/cdn/v1/originGroups/{origin_group_id}BV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cdn.v1.origin_group_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn'
  _globals['_GETORIGINGROUPREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_GETORIGINGROUPREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETORIGINGROUPREQUEST'].fields_by_name['origin_group_id']._loaded_options = None
  _globals['_GETORIGINGROUPREQUEST'].fields_by_name['origin_group_id']._serialized_options = b'\372\3071\002>0'
  _globals['_LISTORIGINGROUPSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTORIGINGROUPSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTORIGINGROUPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTORIGINGROUPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTORIGINGROUPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTORIGINGROUPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATEORIGINGROUPREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEORIGINGROUPREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEORIGINGROUPMETADATA'].fields_by_name['origin_group_id']._loaded_options = None
  _globals['_CREATEORIGINGROUPMETADATA'].fields_by_name['origin_group_id']._serialized_options = b'\372\3071\002>0'
  _globals['_UPDATEORIGINGROUPREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_UPDATEORIGINGROUPREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEORIGINGROUPREQUEST'].fields_by_name['origin_group_id']._loaded_options = None
  _globals['_UPDATEORIGINGROUPREQUEST'].fields_by_name['origin_group_id']._serialized_options = b'\372\3071\002>0'
  _globals['_UPDATEORIGINGROUPMETADATA'].fields_by_name['origin_group_id']._loaded_options = None
  _globals['_UPDATEORIGINGROUPMETADATA'].fields_by_name['origin_group_id']._serialized_options = b'\372\3071\002>0'
  _globals['_DELETEORIGINGROUPREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_DELETEORIGINGROUPREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEORIGINGROUPREQUEST'].fields_by_name['origin_group_id']._loaded_options = None
  _globals['_DELETEORIGINGROUPREQUEST'].fields_by_name['origin_group_id']._serialized_options = b'\372\3071\002>0'
  _globals['_DELETEORIGINGROUPMETADATA'].fields_by_name['origin_group_id']._loaded_options = None
  _globals['_DELETEORIGINGROUPMETADATA'].fields_by_name['origin_group_id']._serialized_options = b'\372\3071\002>0'
  _globals['_ORIGINGROUPSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_ORIGINGROUPSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002(\022&/cdn/v1/originGroups/{origin_group_id}'
  _globals['_ORIGINGROUPSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_ORIGINGROUPSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\026\022\024/cdn/v1/originGroups'
  _globals['_ORIGINGROUPSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_ORIGINGROUPSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*(\n\031CreateOriginGroupMetadata\022\013OriginGroup\202\323\344\223\002\031\"\024/cdn/v1/originGroups:\001*'
  _globals['_ORIGINGROUPSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_ORIGINGROUPSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateOriginGroupMetadata\022\013OriginGroup\202\323\344\223\002\0312\024/cdn/v1/originGroups:\001*'
  _globals['_ORIGINGROUPSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_ORIGINGROUPSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*2\n\031DeleteOriginGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\002(*&/cdn/v1/originGroups/{origin_group_id}'
  _globals['_GETORIGINGROUPREQUEST']._serialized_start=312
  _globals['_GETORIGINGROUPREQUEST']._serialized_end=401
  _globals['_LISTORIGINGROUPSREQUEST']._serialized_start=403
  _globals['_LISTORIGINGROUPSREQUEST']._serialized_end=523
  _globals['_LISTORIGINGROUPSRESPONSE']._serialized_start=525
  _globals['_LISTORIGINGROUPSRESPONSE']._serialized_end=633
  _globals['_CREATEORIGINGROUPREQUEST']._serialized_start=636
  _globals['_CREATEORIGINGROUPREQUEST']._serialized_end=830
  _globals['_CREATEORIGINGROUPMETADATA']._serialized_start=832
  _globals['_CREATEORIGINGROUPMETADATA']._serialized_end=892
  _globals['_UPDATEORIGINGROUPREQUEST']._serialized_start=895
  _globals['_UPDATEORIGINGROUPREQUEST']._serialized_end=1135
  _globals['_UPDATEORIGINGROUPMETADATA']._serialized_start=1137
  _globals['_UPDATEORIGINGROUPMETADATA']._serialized_end=1197
  _globals['_DELETEORIGINGROUPREQUEST']._serialized_start=1199
  _globals['_DELETEORIGINGROUPREQUEST']._serialized_end=1291
  _globals['_DELETEORIGINGROUPMETADATA']._serialized_start=1293
  _globals['_DELETEORIGINGROUPMETADATA']._serialized_end=1353
  _globals['_ORIGINGROUPSERVICE']._serialized_start=1356
  _globals['_ORIGINGROUPSERVICE']._serialized_end=2177
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.rpc.status_pb2
import sys
import typing
import yandex.cloud.ai.batch_inference.v1.inference_options_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class BatchInferenceTask(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BatchInferenceTask._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: BatchInferenceTask._Status.ValueType  # 0
        CREATED: BatchInferenceTask._Status.ValueType  # 1
        PENDING: BatchInferenceTask._Status.ValueType  # 2
        IN_PROGRESS: BatchInferenceTask._Status.ValueType  # 3
        COMPLETED: BatchInferenceTask._Status.ValueType  # 4
        FAILED: BatchInferenceTask._Status.ValueType  # 5
        CANCELED: BatchInferenceTask._Status.ValueType  # 6

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: BatchInferenceTask.Status.ValueType  # 0
    CREATED: BatchInferenceTask.Status.ValueType  # 1
    PENDING: BatchInferenceTask.Status.ValueType  # 2
    IN_PROGRESS: BatchInferenceTask.Status.ValueType  # 3
    COMPLETED: BatchInferenceTask.Status.ValueType  # 4
    FAILED: BatchInferenceTask.Status.ValueType  # 5
    CANCELED: BatchInferenceTask.Status.ValueType  # 6

    @typing.final
    class ErrorsInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class LineError(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            LINE_NUMBER_FIELD_NUMBER: builtins.int
            MESSAGE_FIELD_NUMBER: builtins.int
            line_number: builtins.int
            message: builtins.str
            def __init__(
                self,
                *,
                line_number: builtins.int = ...,
                message: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["line_number", b"line_number", "message", b"message"]) -> None: ...

        @typing.final
        class BatchError(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            BATCH_NUMBER_FIELD_NUMBER: builtins.int
            FIRST_LINE_FIELD_NUMBER: builtins.int
            LAST_LINE_FIELD_NUMBER: builtins.int
            MESSAGE_FIELD_NUMBER: builtins.int
            batch_number: builtins.int
            first_line: builtins.int
            """Range of lines in batch"""
            last_line: builtins.int
            message: builtins.str
            def __init__(
                self,
                *,
                batch_number: builtins.int = ...,
                first_line: builtins.int = ...,
                last_line: builtins.int = ...,
                message: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["batch_number", b"batch_number", "first_line", b"first_line", "last_line", b"last_line", "message", b"message"]) -> None: ...

        STATUS_FIELD_NUMBER: builtins.int
        LINE_ERRORS_FIELD_NUMBER: builtins.int
        BATCH_ERRORS_FIELD_NUMBER: builtins.int
        @property
        def status(self) -> google.rpc.status_pb2.Status:
            """If set and not OK - task failed"""

        @property
        def line_errors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BatchInferenceTask.ErrorsInfo.LineError]:
            """Errors by lines"""

        @property
        def batch_errors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BatchInferenceTask.ErrorsInfo.BatchError]:
            """Errors by batches"""

        def __init__(
            self,
            *,
            status: google.rpc.status_pb2.Status | None = ...,
            line_errors: collections.abc.Iterable[global___BatchInferenceTask.ErrorsInfo.LineError] | None = ...,
            batch_errors: collections.abc.Iterable[global___BatchInferenceTask.ErrorsInfo.BatchError] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["status", b"status"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["batch_errors", b"batch_errors", "line_errors", b"line_errors", "status", b"status"]) -> None: ...

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TASK_ID_FIELD_NUMBER: builtins.int
    OPERATION_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    MODEL_URI_FIELD_NUMBER: builtins.int
    SOURCE_DATASET_ID_FIELD_NUMBER: builtins.int
    COMPLETION_REQUEST_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESULT_DATASET_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    FINISHED_AT_FIELD_NUMBER: builtins.int
    ERRORS_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    operation_id: builtins.str
    folder_id: builtins.str
    model_uri: builtins.str
    source_dataset_id: builtins.str
    status: global___BatchInferenceTask.Status.ValueType
    result_dataset_id: builtins.str
    created_by: builtins.str
    @property
    def completion_request(self) -> yandex.cloud.ai.batch_inference.v1.inference_options_pb2.BatchCompletionRequest: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def finished_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def errors(self) -> global___BatchInferenceTask.ErrorsInfo: ...
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
        operation_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        model_uri: builtins.str = ...,
        source_dataset_id: builtins.str = ...,
        completion_request: yandex.cloud.ai.batch_inference.v1.inference_options_pb2.BatchCompletionRequest | None = ...,
        status: global___BatchInferenceTask.Status.ValueType = ...,
        result_dataset_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        created_by: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        finished_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        errors: global___BatchInferenceTask.ErrorsInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["completion_request", b"completion_request", "created_at", b"created_at", "errors", b"errors", "finished_at", b"finished_at", "request", b"request", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["completion_request", b"completion_request", "created_at", b"created_at", "created_by", b"created_by", "errors", b"errors", "finished_at", b"finished_at", "folder_id", b"folder_id", "labels", b"labels", "model_uri", b"model_uri", "operation_id", b"operation_id", "request", b"request", "result_dataset_id", b"result_dataset_id", "source_dataset_id", b"source_dataset_id", "started_at", b"started_at", "status", b"status", "task_id", b"task_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["request", b"request"]) -> typing.Literal["completion_request"] | None: ...

global___BatchInferenceTask = BatchInferenceTask



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _UserPasswordEncryption:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UserPasswordEncryptionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UserPasswordEncryption.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    USER_PASSWORD_ENCRYPTION_UNSPECIFIED: _UserPasswordEncryption.ValueType  # 0
    USER_PASSWORD_ENCRYPTION_MD5: _UserPasswordEncryption.ValueType  # 1
    USER_PASSWORD_ENCRYPTION_SCRAM_SHA_256: _UserPasswordEncryption.ValueType  # 2

class UserPasswordEncryption(_UserPasswordEncryption, metaclass=_UserPasswordEncryptionEnumTypeWrapper): ...

USER_PASSWORD_ENCRYPTION_UNSPECIFIED: UserPasswordEncryption.ValueType  # 0
USER_PASSWORD_ENCRYPTION_MD5: UserPasswordEncryption.ValueType  # 1
USER_PASSWORD_ENCRYPTION_SCRAM_SHA_256: UserPasswordEncryption.ValueType  # 2
global___UserPasswordEncryption = UserPasswordEncryption

@typing.final
class User(google.protobuf.message.Message):
    """A PostgreSQL User resource. For more information, see
    the [Developer's Guide](/docs/managed-postgresql/concepts).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    CONN_LIMIT_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    GRANTS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    USER_PASSWORD_ENCRYPTION_FIELD_NUMBER: builtins.int
    CONNECTION_MANAGER_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the PostgreSQL user."""
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster the user belongs to."""
    conn_limit: builtins.int
    """Maximum number of database connections available to the user.

    When used in session pooling, this setting limits the number of connections to every single host in PostgreSQL cluster. In this case, the setting's value must be greater than the total number of connections that backend services can open to access the PostgreSQL cluster. The setting's value should not exceed the value of the [Cluster.config.postgresql_config_12.effective_config.max_connections] setting.

    When used in transaction pooling, this setting limits the number of user's active transactions; therefore, in this mode user can open thousands of connections, but only `N` concurrent connections will be opened, where `N` is the value of the setting.

    Minimum value: `10` (default: `50`), when used in session pooling.
    """
    user_password_encryption: global___UserPasswordEncryption.ValueType
    """Password-based authentication method for user.
    Possible values are `` USER_PASSWORD_ENCRYPTION_MD5 `` or `` USER_PASSWORD_ENCRYPTION_SCRAM_SHA_256 ``.
    The default is `` password_encryption `` setting for cluster.
    """
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]:
        """Set of permissions granted to the user to access specific databases."""

    @property
    def settings(self) -> global___UserSettings: ...
    @property
    def login(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """This flag defines whether the user can login to a PostgreSQL database.

        Default value: `true` (login is allowed).
        """

    @property
    def grants(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A set of roles and privileges that are granted to the user.

        For more information, see [the documentation](/docs/managed-postgresql/operations/grant).
        """

    @property
    def deletion_protection(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Determines whether the user deletion protection is enabled.

        The default value is `unspecified`. In this case, the user configuration inherits the cluster's deletion protection settings.
        """

    @property
    def connection_manager(self) -> global___ConnectionManager:
        """Connection Manager Connection and settings associated with user. Read only field."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        permissions: collections.abc.Iterable[global___Permission] | None = ...,
        conn_limit: builtins.int = ...,
        settings: global___UserSettings | None = ...,
        login: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        grants: collections.abc.Iterable[builtins.str] | None = ...,
        deletion_protection: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        user_password_encryption: global___UserPasswordEncryption.ValueType = ...,
        connection_manager: global___ConnectionManager | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection_manager", b"connection_manager", "deletion_protection", b"deletion_protection", "login", b"login", "settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "conn_limit", b"conn_limit", "connection_manager", b"connection_manager", "deletion_protection", b"deletion_protection", "grants", b"grants", "login", b"login", "name", b"name", "permissions", b"permissions", "settings", b"settings", "user_password_encryption", b"user_password_encryption"]) -> None: ...

global___User = User

@typing.final
class Permission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_NAME_FIELD_NUMBER: builtins.int
    database_name: builtins.str
    """Name of the database that the permission grants access to."""
    def __init__(
        self,
        *,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_name", b"database_name"]) -> None: ...

global___Permission = Permission

@typing.final
class ConnectionManager(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    """ID of Connection Manager Connection"""
    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id"]) -> None: ...

global___ConnectionManager = ConnectionManager

@typing.final
class UserSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    CONN_LIMIT_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    GRANTS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    USER_PASSWORD_ENCRYPTION_FIELD_NUMBER: builtins.int
    GENERATE_PASSWORD_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the PostgreSQL user."""
    password: builtins.str
    """Password of the PostgreSQL user."""
    user_password_encryption: global___UserPasswordEncryption.ValueType
    """Password-based authentication method for user.
    Possible values are `` USER_PASSWORD_ENCRYPTION_MD5 `` or `` USER_PASSWORD_ENCRYPTION_SCRAM_SHA_256 ``.
    The default is `` password_encryption `` setting for cluster.
    """
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]:
        """Set of permissions to grant to the user to access specific databases."""

    @property
    def conn_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum number of database connections that should be available to the user.

        When used in session pooling, this setting limits the number of connections to every single host in PostgreSQL cluster. In this case, the setting's value must be greater than the total number of connections that backend services can open to access the PostgreSQL cluster. The setting's value should not exceed the value of the [Cluster.config.postgresql_config_12.effective_config.max_connections] setting.

        When used in transaction pooling, this setting limits the number of user's active transactions; therefore, in this mode user can open thousands of connections, but only `N` concurrent connections will be opened, where `N` is the value of the setting.

        Minimum value: `10` (default: `50`), when used in session pooling.
        """

    @property
    def settings(self) -> global___UserSettings:
        """PostgreSQL settings for the user."""

    @property
    def login(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """This flag defines whether the user can login to a PostgreSQL database.

        Default value: `true` (login is allowed).
        """

    @property
    def grants(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A set of roles and privileges that are granted to the user.

        For more information, see [the documentation](/docs/managed-postgresql/operations/grant).
        """

    @property
    def deletion_protection(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Deletion Protection inhibits deletion of the user

        Default value: `unspecified` (inherits cluster's deletion_protection)
        """

    @property
    def generate_password(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Generate password using Connection Manager."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        password: builtins.str = ...,
        permissions: collections.abc.Iterable[global___Permission] | None = ...,
        conn_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        settings: global___UserSettings | None = ...,
        login: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        grants: collections.abc.Iterable[builtins.str] | None = ...,
        deletion_protection: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        user_password_encryption: global___UserPasswordEncryption.ValueType = ...,
        generate_password: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["conn_limit", b"conn_limit", "deletion_protection", b"deletion_protection", "generate_password", b"generate_password", "login", b"login", "settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_limit", b"conn_limit", "deletion_protection", b"deletion_protection", "generate_password", b"generate_password", "grants", b"grants", "login", b"login", "name", b"name", "password", b"password", "permissions", b"permissions", "settings", b"settings", "user_password_encryption", b"user_password_encryption"]) -> None: ...

global___UserSpec = UserSpec

@typing.final
class PGAuditSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _PGAuditSettingsLog:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PGAuditSettingsLogEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PGAuditSettings._PGAuditSettingsLog.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PG_AUDIT_SETTINGS_LOG_UNSPECIFIED: PGAuditSettings._PGAuditSettingsLog.ValueType  # 0
        PG_AUDIT_SETTINGS_LOG_READ: PGAuditSettings._PGAuditSettingsLog.ValueType  # 1
        PG_AUDIT_SETTINGS_LOG_WRITE: PGAuditSettings._PGAuditSettingsLog.ValueType  # 2
        PG_AUDIT_SETTINGS_LOG_FUNCTION: PGAuditSettings._PGAuditSettingsLog.ValueType  # 3
        PG_AUDIT_SETTINGS_LOG_ROLE: PGAuditSettings._PGAuditSettingsLog.ValueType  # 4
        PG_AUDIT_SETTINGS_LOG_DDL: PGAuditSettings._PGAuditSettingsLog.ValueType  # 5
        PG_AUDIT_SETTINGS_LOG_MISC: PGAuditSettings._PGAuditSettingsLog.ValueType  # 6
        PG_AUDIT_SETTINGS_LOG_MISC_SET: PGAuditSettings._PGAuditSettingsLog.ValueType  # 7

    class PGAuditSettingsLog(_PGAuditSettingsLog, metaclass=_PGAuditSettingsLogEnumTypeWrapper): ...
    PG_AUDIT_SETTINGS_LOG_UNSPECIFIED: PGAuditSettings.PGAuditSettingsLog.ValueType  # 0
    PG_AUDIT_SETTINGS_LOG_READ: PGAuditSettings.PGAuditSettingsLog.ValueType  # 1
    PG_AUDIT_SETTINGS_LOG_WRITE: PGAuditSettings.PGAuditSettingsLog.ValueType  # 2
    PG_AUDIT_SETTINGS_LOG_FUNCTION: PGAuditSettings.PGAuditSettingsLog.ValueType  # 3
    PG_AUDIT_SETTINGS_LOG_ROLE: PGAuditSettings.PGAuditSettingsLog.ValueType  # 4
    PG_AUDIT_SETTINGS_LOG_DDL: PGAuditSettings.PGAuditSettingsLog.ValueType  # 5
    PG_AUDIT_SETTINGS_LOG_MISC: PGAuditSettings.PGAuditSettingsLog.ValueType  # 6
    PG_AUDIT_SETTINGS_LOG_MISC_SET: PGAuditSettings.PGAuditSettingsLog.ValueType  # 7

    LOG_FIELD_NUMBER: builtins.int
    @property
    def log(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___PGAuditSettings.PGAuditSettingsLog.ValueType]:
        """Defines which user queries will be written to the audit log. Corresponds to the [Pg audit log](https://yandex.cloud/en/docs/managed-postgresql/concepts/settings-list#setting-pg-audit-log) user setting.

        The possible values are the following:

        * PG_AUDIT_SETTINGS_LOG_READ: `SELECT` and `COPY` queries are logged if the data source is a relation or query.
        * PG_AUDIT_SETTINGS_LOG_WRITE: `INSERT`, `UPDATE`, `DELETE`, `TRUNCATE`, and `COPY` queries are logged if the data target is a relation.
        * PG_AUDIT_SETTINGS_LOG_FUNCTION: Function invocations and `DO` sections are logged.
        * PG_AUDIT_SETTINGS_LOG_ROLE: Statements related to role and privilege management, such as `GRANT`, `REVOKE`, or `CREATE/ALTER/DROP ROLE`, are logged.
        * PG_AUDIT_SETTINGS_LOG_DDL: Any `DDL` statements that do not belong to the `ROLE` class are logged.
        * PG_AUDIT_SETTINGS_LOG_MISC: Miscellaneous commands, such as `DISCARD`, `FETCH`, `CHECKPOINT`, `VACUUM`, and `SET`, are logged.
        * PG_AUDIT_SETTINGS_LOG_MISC_SET: Miscellaneous `SET` commands, e.g., `SET ROLE`, are logged.

        The default value is PG_AUDIT_SETTINGS_LOG_UNSPECIFIED. In this case, the parameter is not configured.
        """

    def __init__(
        self,
        *,
        log: collections.abc.Iterable[global___PGAuditSettings.PGAuditSettingsLog.ValueType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["log", b"log"]) -> None: ...

global___PGAuditSettings = PGAuditSettings

@typing.final
class UserSettings(google.protobuf.message.Message):
    """PostgreSQL user settings."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _SynchronousCommit:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SynchronousCommitEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UserSettings._SynchronousCommit.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SYNCHRONOUS_COMMIT_UNSPECIFIED: UserSettings._SynchronousCommit.ValueType  # 0
        SYNCHRONOUS_COMMIT_ON: UserSettings._SynchronousCommit.ValueType  # 1
        """Success is reported to the client if the data is in WAL (Write-Ahead Log), and WAL is written to the storage of both the master and its synchronous standby server. Default value."""
        SYNCHRONOUS_COMMIT_OFF: UserSettings._SynchronousCommit.ValueType  # 2
        """Success is reported to the client even if the data is not in WAL.
        There is no synchronous write operation, data may be loss in case of storage subsystem failure.
        """
        SYNCHRONOUS_COMMIT_LOCAL: UserSettings._SynchronousCommit.ValueType  # 3
        """Success is reported to the client if the data is in WAL, and WAL is written to the storage of the master server.
        The transaction may be lost due to storage subsystem failure on the master server.
        """
        SYNCHRONOUS_COMMIT_REMOTE_WRITE: UserSettings._SynchronousCommit.ValueType  # 4
        """Success is reported to the client if the data is in WAL, WAL is written to the storage of the master server, and the server's synchronous standby indicates that it has received WAL and written it out to its operating system.
        The transaction may be lost due to simultaneous storage subsystem failure on the master and operating system's failure on the synchronous standby.
        """
        SYNCHRONOUS_COMMIT_REMOTE_APPLY: UserSettings._SynchronousCommit.ValueType  # 5
        """Success is reported to the client if the data is in WAL (Write-Ahead Log), WAL is written to the storage of the master server, and its synchronous standby indicates that it has received WAL and applied it.
        The transaction may be lost due to irrecoverably failure of both the master and its synchronous standby.
        """

    class SynchronousCommit(_SynchronousCommit, metaclass=_SynchronousCommitEnumTypeWrapper): ...
    SYNCHRONOUS_COMMIT_UNSPECIFIED: UserSettings.SynchronousCommit.ValueType  # 0
    SYNCHRONOUS_COMMIT_ON: UserSettings.SynchronousCommit.ValueType  # 1
    """Success is reported to the client if the data is in WAL (Write-Ahead Log), and WAL is written to the storage of both the master and its synchronous standby server. Default value."""
    SYNCHRONOUS_COMMIT_OFF: UserSettings.SynchronousCommit.ValueType  # 2
    """Success is reported to the client even if the data is not in WAL.
    There is no synchronous write operation, data may be loss in case of storage subsystem failure.
    """
    SYNCHRONOUS_COMMIT_LOCAL: UserSettings.SynchronousCommit.ValueType  # 3
    """Success is reported to the client if the data is in WAL, and WAL is written to the storage of the master server.
    The transaction may be lost due to storage subsystem failure on the master server.
    """
    SYNCHRONOUS_COMMIT_REMOTE_WRITE: UserSettings.SynchronousCommit.ValueType  # 4
    """Success is reported to the client if the data is in WAL, WAL is written to the storage of the master server, and the server's synchronous standby indicates that it has received WAL and written it out to its operating system.
    The transaction may be lost due to simultaneous storage subsystem failure on the master and operating system's failure on the synchronous standby.
    """
    SYNCHRONOUS_COMMIT_REMOTE_APPLY: UserSettings.SynchronousCommit.ValueType  # 5
    """Success is reported to the client if the data is in WAL (Write-Ahead Log), WAL is written to the storage of the master server, and its synchronous standby indicates that it has received WAL and applied it.
    The transaction may be lost due to irrecoverably failure of both the master and its synchronous standby.
    """

    class _LogStatement:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LogStatementEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UserSettings._LogStatement.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOG_STATEMENT_UNSPECIFIED: UserSettings._LogStatement.ValueType  # 0
        LOG_STATEMENT_NONE: UserSettings._LogStatement.ValueType  # 1
        """Logs none of SQL statements. Default value."""
        LOG_STATEMENT_DDL: UserSettings._LogStatement.ValueType  # 2
        """Logs all data definition statements (such as `CREATE`, `ALTER`, `DROP` and others)."""
        LOG_STATEMENT_MOD: UserSettings._LogStatement.ValueType  # 3
        """Logs all statements that fall in the `LOG_STATEMENT_DDL` category plus data-modifying statements (such as `INSERT`, `UPDATE` and others)."""
        LOG_STATEMENT_ALL: UserSettings._LogStatement.ValueType  # 4
        """Logs all SQL statements."""

    class LogStatement(_LogStatement, metaclass=_LogStatementEnumTypeWrapper): ...
    LOG_STATEMENT_UNSPECIFIED: UserSettings.LogStatement.ValueType  # 0
    LOG_STATEMENT_NONE: UserSettings.LogStatement.ValueType  # 1
    """Logs none of SQL statements. Default value."""
    LOG_STATEMENT_DDL: UserSettings.LogStatement.ValueType  # 2
    """Logs all data definition statements (such as `CREATE`, `ALTER`, `DROP` and others)."""
    LOG_STATEMENT_MOD: UserSettings.LogStatement.ValueType  # 3
    """Logs all statements that fall in the `LOG_STATEMENT_DDL` category plus data-modifying statements (such as `INSERT`, `UPDATE` and others)."""
    LOG_STATEMENT_ALL: UserSettings.LogStatement.ValueType  # 4
    """Logs all SQL statements."""

    class _TransactionIsolation:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TransactionIsolationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UserSettings._TransactionIsolation.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TRANSACTION_ISOLATION_UNSPECIFIED: UserSettings._TransactionIsolation.ValueType  # 0
        TRANSACTION_ISOLATION_READ_UNCOMMITTED: UserSettings._TransactionIsolation.ValueType  # 1
        """This level behaves like `TRANSACTION_ISOLATION_READ_COMMITTED` in PostgreSQL."""
        TRANSACTION_ISOLATION_READ_COMMITTED: UserSettings._TransactionIsolation.ValueType  # 2
        """On this level query sees only data committed before the query began. Default value."""
        TRANSACTION_ISOLATION_REPEATABLE_READ: UserSettings._TransactionIsolation.ValueType  # 3
        """On this level all subsequent queries in a transaction will see the same rows, that were read by the first `SELECT` or `INSERT` query in this transaction, unchanged (these rows are locked during the first query)."""
        TRANSACTION_ISOLATION_SERIALIZABLE: UserSettings._TransactionIsolation.ValueType  # 4
        """This level provides the strictest transaction isolation.
        All queries in the current transaction see only the rows that were fixed prior to execution of the first `SELECT` or `INSERT` query in this transaction.
        If read and write operations in a concurrent set of serializable transactions overlap and this may cause an inconsistency that is not possible during the serial transaction execution, then one of the transaction will be rolled back, triggering a serialization failure.
        """

    class TransactionIsolation(_TransactionIsolation, metaclass=_TransactionIsolationEnumTypeWrapper): ...
    TRANSACTION_ISOLATION_UNSPECIFIED: UserSettings.TransactionIsolation.ValueType  # 0
    TRANSACTION_ISOLATION_READ_UNCOMMITTED: UserSettings.TransactionIsolation.ValueType  # 1
    """This level behaves like `TRANSACTION_ISOLATION_READ_COMMITTED` in PostgreSQL."""
    TRANSACTION_ISOLATION_READ_COMMITTED: UserSettings.TransactionIsolation.ValueType  # 2
    """On this level query sees only data committed before the query began. Default value."""
    TRANSACTION_ISOLATION_REPEATABLE_READ: UserSettings.TransactionIsolation.ValueType  # 3
    """On this level all subsequent queries in a transaction will see the same rows, that were read by the first `SELECT` or `INSERT` query in this transaction, unchanged (these rows are locked during the first query)."""
    TRANSACTION_ISOLATION_SERIALIZABLE: UserSettings.TransactionIsolation.ValueType  # 4
    """This level provides the strictest transaction isolation.
    All queries in the current transaction see only the rows that were fixed prior to execution of the first `SELECT` or `INSERT` query in this transaction.
    If read and write operations in a concurrent set of serializable transactions overlap and this may cause an inconsistency that is not possible during the serial transaction execution, then one of the transaction will be rolled back, triggering a serialization failure.
    """

    class _PoolingMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PoolingModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UserSettings._PoolingMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        POOLING_MODE_UNSPECIFIED: UserSettings._PoolingMode.ValueType  # 0
        SESSION: UserSettings._PoolingMode.ValueType  # 1
        """Server connection will be assigned to it for the whole duration the client stays connected. Default value."""
        TRANSACTION: UserSettings._PoolingMode.ValueType  # 2
        """Server connection is assigned to a client only during a transaction."""
        STATEMENT: UserSettings._PoolingMode.ValueType  # 3
        """Server connection will be put back into the pool immediately after a query completes."""

    class PoolingMode(_PoolingMode, metaclass=_PoolingModeEnumTypeWrapper): ...
    POOLING_MODE_UNSPECIFIED: UserSettings.PoolingMode.ValueType  # 0
    SESSION: UserSettings.PoolingMode.ValueType  # 1
    """Server connection will be assigned to it for the whole duration the client stays connected. Default value."""
    TRANSACTION: UserSettings.PoolingMode.ValueType  # 2
    """Server connection is assigned to a client only during a transaction."""
    STATEMENT: UserSettings.PoolingMode.ValueType  # 3
    """Server connection will be put back into the pool immediately after a query completes."""

    DEFAULT_TRANSACTION_ISOLATION_FIELD_NUMBER: builtins.int
    LOCK_TIMEOUT_FIELD_NUMBER: builtins.int
    LOG_MIN_DURATION_STATEMENT_FIELD_NUMBER: builtins.int
    SYNCHRONOUS_COMMIT_FIELD_NUMBER: builtins.int
    TEMP_FILE_LIMIT_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_FIELD_NUMBER: builtins.int
    POOL_MODE_FIELD_NUMBER: builtins.int
    PREPARED_STATEMENTS_POOLING_FIELD_NUMBER: builtins.int
    CATCHUP_TIMEOUT_FIELD_NUMBER: builtins.int
    WAL_SENDER_TIMEOUT_FIELD_NUMBER: builtins.int
    IDLE_IN_TRANSACTION_SESSION_TIMEOUT_FIELD_NUMBER: builtins.int
    STATEMENT_TIMEOUT_FIELD_NUMBER: builtins.int
    PGAUDIT_FIELD_NUMBER: builtins.int
    default_transaction_isolation: global___UserSettings.TransactionIsolation.ValueType
    """SQL sets an isolation level for each transaction.
    This setting defines the default isolation level to be set for all new SQL transactions.

    For more information, see the [PostgreSQL documentation](https://www.postgresql.org/docs/current/transaction-iso.html).
    """
    synchronous_commit: global___UserSettings.SynchronousCommit.ValueType
    """This setting defines whether DBMS will commit transaction in a synchronous way.

    When synchronization is enabled, cluster waits for the synchronous operations to be completed prior to reporting `success` to the client.
    These operations guarantee different levels of the data safety and visibility in the cluster.

    For more information, see the [PostgreSQL documentation](https://www.postgresql.org/docs/current/runtime-config-wal.html#GUC-SYNCHRONOUS-COMMIT).
    """
    log_statement: global___UserSettings.LogStatement.ValueType
    """This setting specifies which SQL statements should be logged (on the user level).

    For more information, see the [PostgreSQL documentation](https://www.postgresql.org/docs/current/runtime-config-logging.html).
    """
    pool_mode: global___UserSettings.PoolingMode.ValueType
    """Mode that the connection pooler is working in with specified user.

    For more information, see the [Odyssey documentation](https://github.com/yandex/odyssey/blob/master/documentation/configuration.md#pool-string).
    """
    @property
    def lock_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum time (in milliseconds) for any statement to wait for acquiring a lock on an table, index, row or other database object.
        If the wait time is longer than the specified amount, then this statement is aborted.

        Default value: `0` (no control is enforced, a statement waiting time is unlimited).
        """

    @property
    def log_min_duration_statement(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """This setting controls logging of the duration of statements.

        The duration of each completed statement will be logged if the statement ran for at least the specified amount of time (in milliseconds).
        E.g., if this setting's value is set to `500`, a statement that took 300 milliseconds to complete will not be logged; on the other hand, the one that took 2000 milliseconds to complete, will be logged.

        Value of `0` forces PostgreSQL to log the duration of all statements.

        Value of `-1` (default) disables logging of the duration of statements.

        For more information, see the [PostgreSQL documentation](https://www.postgresql.org/docs/current/runtime-config-logging.html).
        """

    @property
    def temp_file_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum storage space size (in kilobytes) that a single process can use to create temporary files.
        If a transaction exceeds this limit during execution, it will be aborted.

        A huge query may not fit into a server's RAM, therefore PostgreSQL will use some storage to store and execute such a query. Too big queries can make excessive use of the storage system, effectively making other quieries to run slow. This setting prevents execution of a big queries that can influence other queries by limiting size of temporary files.
        """

    @property
    def prepared_statements_pooling(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """User can use prepared statements with transaction pooling.

        For more information, see the [PostgreSQL documentation](https://www.postgresql.org/docs/current/sql-prepare.html).
        """

    @property
    def catchup_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The connection pooler setting. It determines the maximum allowed replication lag (in seconds).
        Pooler will reject connections to the replica with a lag above this threshold.
        It can be useful to prevent application from reading stale data.

        Default value: 0

        Value of `0` disables this mechanism
        """

    @property
    def wal_sender_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum time (in milliseconds) to wait for WAL replication (can be set only for PostgreSQL 12+)
        Terminate replication connections that are inactive for longer than this amount of time. 

        Default value: `60000` (60 seconds).

        Value of `0` disables the timeout mechanism.

        For more information, see the [PostgreSQL documentation](https://www.postgresql.org/docs/current/runtime-config-replication.html).
        """

    @property
    def idle_in_transaction_session_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum allowed idle time, in milliseconds, between queries while in a transaction.

        The default value is `0`, which disables the timeout.

        For more information, see the [PostgreSQL documentation](https://www.postgresql.org/docs/current/runtime-config-client.html).
        in milliseconds.
        """

    @property
    def statement_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum time (in milliseconds) to wait for statement.
        The timeout is measured from the time a command arrives at the server until it is completed by the server. 

        If `log_min_error_statement` is set to ERROR or lower, the statement that timed out will also be logged.

        Value of `0` (default) disables the timeout

        For more information, see the [PostgreSQL documentation](https://www.postgresql.org/docs/current/runtime-config-client.html).
        """

    @property
    def pgaudit(self) -> global___PGAuditSettings:
        """Settings of the [PostgreSQL Audit Extension](https://www.pgaudit.org/) (pgaudit)."""

    def __init__(
        self,
        *,
        default_transaction_isolation: global___UserSettings.TransactionIsolation.ValueType = ...,
        lock_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_min_duration_statement: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        synchronous_commit: global___UserSettings.SynchronousCommit.ValueType = ...,
        temp_file_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_statement: global___UserSettings.LogStatement.ValueType = ...,
        pool_mode: global___UserSettings.PoolingMode.ValueType = ...,
        prepared_statements_pooling: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        catchup_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        wal_sender_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        idle_in_transaction_session_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        statement_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        pgaudit: global___PGAuditSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["catchup_timeout", b"catchup_timeout", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "lock_timeout", b"lock_timeout", "log_min_duration_statement", b"log_min_duration_statement", "pgaudit", b"pgaudit", "prepared_statements_pooling", b"prepared_statements_pooling", "statement_timeout", b"statement_timeout", "temp_file_limit", b"temp_file_limit", "wal_sender_timeout", b"wal_sender_timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["catchup_timeout", b"catchup_timeout", "default_transaction_isolation", b"default_transaction_isolation", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "lock_timeout", b"lock_timeout", "log_min_duration_statement", b"log_min_duration_statement", "log_statement", b"log_statement", "pgaudit", b"pgaudit", "pool_mode", b"pool_mode", "prepared_statements_pooling", b"prepared_statements_pooling", "statement_timeout", b"statement_timeout", "synchronous_commit", b"synchronous_commit", "temp_file_limit", b"temp_file_limit", "wal_sender_timeout", b"wal_sender_timeout"]) -> None: ...

global___UserSettings = UserSettings



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/opensearch/v1/extension_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/opensearch/v1/extension_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.opensearch.v1 import extension_pb2 as yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_extension__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/mdb/opensearch/v1/extension_service.proto\x12\x1eyandex.cloud.mdb.opensearch.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a.yandex/cloud/mdb/opensearch/v1/extension.proto\x1a&yandex/cloud/operation/operation.proto\"S\n\x13GetExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"w\n\x15ListExtensionsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"p\n\x16ListExtensionsResponse\x12=\n\nextensions\x18\x01 \x03(\x0b\x32).yandex.cloud.mdb.opensearch.v1.Extension\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"V\n\x16\x44\x65leteExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"W\n\x17\x44\x65leteExtensionMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"f\n\x16UpdateExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\x08\"W\n\x17UpdateExtensionMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8d\x01\n\x16\x43reateExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12K\n\x0e\x65xtension_spec\x18\x05 \x01(\x0b\x32-.yandex.cloud.mdb.opensearch.v1.ExtensionSpecB\x04\xe8\xc7\x31\x01J\x04\x08\x02\x10\x05\"W\n\x17\x43reateExtensionMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xa1\x08\n\x10\x45xtensionService\x12\xb5\x01\n\x03Get\x12\x33.yandex.cloud.mdb.opensearch.v1.GetExtensionRequest\x1a).yandex.cloud.mdb.opensearch.v1.Extension\"N\x82\xd3\xe4\x93\x02H\x12\x46/managed-opensearch/v1/clusters/{cluster_id}/extensions/{extension_id}\x12\xb6\x01\n\x04List\x12\x35.yandex.cloud.mdb.opensearch.v1.ListExtensionsRequest\x1a\x36.yandex.cloud.mdb.opensearch.v1.ListExtensionsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/managed-opensearch/v1/clusters/{cluster_id}/extensions\x12\xcf\x01\n\x06\x43reate\x12\x36.yandex.cloud.mdb.opensearch.v1.CreateExtensionRequest\x1a!.yandex.cloud.operation.Operation\"j\xb2\xd2*$\n\x17\x43reateExtensionMetadata\x12\tExtension\x82\xd3\xe4\x93\x02<\"7/managed-opensearch/v1/clusters/{cluster_id}/extensions:\x01*\x12\xde\x01\n\x06Update\x12\x36.yandex.cloud.mdb.opensearch.v1.UpdateExtensionRequest\x1a!.yandex.cloud.operation.Operation\"y\xb2\xd2*$\n\x17UpdateExtensionMetadata\x12\tExtension\x82\xd3\xe4\x93\x02K2F/managed-opensearch/v1/clusters/{cluster_id}/extensions/{extension_id}:\x01*\x12\xe8\x01\n\x06\x44\x65lete\x12\x36.yandex.cloud.mdb.opensearch.v1.DeleteExtensionRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\xb2\xd2*0\n\x17\x44\x65leteExtensionMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02H*F/managed-opensearch/v1/clusters/{cluster_id}/extensions/{extension_id}Bs\n\"yandex.cloud.api.mdb.opensearch.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1;opensearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.opensearch.v1.extension_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.opensearch.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1;opensearch'
  _globals['_GETEXTENSIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETEXTENSIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETEXTENSIONREQUEST'].fields_by_name['extension_id']._loaded_options = None
  _globals['_GETEXTENSIONREQUEST'].fields_by_name['extension_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_DELETEEXTENSIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEEXTENSIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEEXTENSIONREQUEST'].fields_by_name['extension_id']._loaded_options = None
  _globals['_DELETEEXTENSIONREQUEST'].fields_by_name['extension_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETEEXTENSIONMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEEXTENSIONMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEEXTENSIONMETADATA'].fields_by_name['extension_id']._loaded_options = None
  _globals['_DELETEEXTENSIONMETADATA'].fields_by_name['extension_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEEXTENSIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEEXTENSIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEEXTENSIONREQUEST'].fields_by_name['extension_id']._loaded_options = None
  _globals['_UPDATEEXTENSIONREQUEST'].fields_by_name['extension_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEEXTENSIONMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEEXTENSIONMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEEXTENSIONMETADATA'].fields_by_name['extension_id']._loaded_options = None
  _globals['_UPDATEEXTENSIONMETADATA'].fields_by_name['extension_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEEXTENSIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATEEXTENSIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEEXTENSIONREQUEST'].fields_by_name['extension_spec']._loaded_options = None
  _globals['_CREATEEXTENSIONREQUEST'].fields_by_name['extension_spec']._serialized_options = b'\350\3071\001'
  _globals['_CREATEEXTENSIONMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATEEXTENSIONMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEEXTENSIONMETADATA'].fields_by_name['extension_id']._loaded_options = None
  _globals['_CREATEEXTENSIONMETADATA'].fields_by_name['extension_id']._serialized_options = b'\350\3071\001'
  _globals['_EXTENSIONSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_EXTENSIONSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002H\022F/managed-opensearch/v1/clusters/{cluster_id}/extensions/{extension_id}'
  _globals['_EXTENSIONSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_EXTENSIONSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\0029\0227/managed-opensearch/v1/clusters/{cluster_id}/extensions'
  _globals['_EXTENSIONSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_EXTENSIONSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*$\n\027CreateExtensionMetadata\022\tExtension\202\323\344\223\002<\"7/managed-opensearch/v1/clusters/{cluster_id}/extensions:\001*'
  _globals['_EXTENSIONSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_EXTENSIONSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*$\n\027UpdateExtensionMetadata\022\tExtension\202\323\344\223\002K2F/managed-opensearch/v1/clusters/{cluster_id}/extensions/{extension_id}:\001*'
  _globals['_EXTENSIONSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_EXTENSIONSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*0\n\027DeleteExtensionMetadata\022\025google.protobuf.Empty\202\323\344\223\002H*F/managed-opensearch/v1/clusters/{cluster_id}/extensions/{extension_id}'
  _globals['_GETEXTENSIONREQUEST']._serialized_start=273
  _globals['_GETEXTENSIONREQUEST']._serialized_end=356
  _globals['_LISTEXTENSIONSREQUEST']._serialized_start=358
  _globals['_LISTEXTENSIONSREQUEST']._serialized_end=477
  _globals['_LISTEXTENSIONSRESPONSE']._serialized_start=479
  _globals['_LISTEXTENSIONSRESPONSE']._serialized_end=591
  _globals['_DELETEEXTENSIONREQUEST']._serialized_start=593
  _globals['_DELETEEXTENSIONREQUEST']._serialized_end=679
  _globals['_DELETEEXTENSIONMETADATA']._serialized_start=681
  _globals['_DELETEEXTENSIONMETADATA']._serialized_end=768
  _globals['_UPDATEEXTENSIONREQUEST']._serialized_start=770
  _globals['_UPDATEEXTENSIONREQUEST']._serialized_end=872
  _globals['_UPDATEEXTENSIONMETADATA']._serialized_start=874
  _globals['_UPDATEEXTENSIONMETADATA']._serialized_end=961
  _globals['_CREATEEXTENSIONREQUEST']._serialized_start=964
  _globals['_CREATEEXTENSIONREQUEST']._serialized_end=1105
  _globals['_CREATEEXTENSIONMETADATA']._serialized_start=1107
  _globals['_CREATEEXTENSIONMETADATA']._serialized_end=1194
  _globals['_EXTENSIONSERVICE']._serialized_start=1197
  _globals['_EXTENSIONSERVICE']._serialized_end=2254
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import yandex.cloud.quotamanager.v1.resource_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetQuotaLimitRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_FIELD_NUMBER: builtins.int
    QUOTA_ID_FIELD_NUMBER: builtins.int
    quota_id: builtins.str
    """The id of the quota to retrieve."""
    @property
    def resource(self) -> yandex.cloud.quotamanager.v1.resource_pb2.Resource:
        """The resource for which the quota limit is being requested."""

    def __init__(
        self,
        *,
        resource: yandex.cloud.quotamanager.v1.resource_pb2.Resource | None = ...,
        quota_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["quota_id", b"quota_id", "resource", b"resource"]) -> None: ...

global___GetQuotaLimitRequest = GetQuotaLimitRequest

@typing.final
class ListQuotaLimitsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    service: builtins.str
    """The service for which quota limits are being requested."""
    page_size: builtins.int
    """The maximum number of quota limits to return per response."""
    page_token: builtins.str
    """Token to retrieve the next page of results. Omitted on the first request."""
    @property
    def resource(self) -> yandex.cloud.quotamanager.v1.resource_pb2.Resource:
        """The resource for which quota limits are being listed."""

    def __init__(
        self,
        *,
        resource: yandex.cloud.quotamanager.v1.resource_pb2.Resource | None = ...,
        service: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "resource", b"resource", "service", b"service"]) -> None: ...

global___ListQuotaLimitsRequest = ListQuotaLimitsRequest

@typing.final
class ListQuotaLimitsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_FIELD_NUMBER: builtins.int
    QUOTA_LIMITS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token to retrieve the next page of results."""
    @property
    def resource(self) -> yandex.cloud.quotamanager.v1.resource_pb2.Resource:
        """The associated resource for these quota limits."""

    @property
    def quota_limits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___QuotaLimit]:
        """List of quota limits for the specified resource and service."""

    def __init__(
        self,
        *,
        resource: yandex.cloud.quotamanager.v1.resource_pb2.Resource | None = ...,
        quota_limits: collections.abc.Iterable[global___QuotaLimit] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "quota_limits", b"quota_limits", "resource", b"resource"]) -> None: ...

global___ListQuotaLimitsResponse = ListQuotaLimitsResponse

@typing.final
class ListServicesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    resource_type: builtins.str
    """The type of resources for which services are being requested."""
    page_size: builtins.int
    """The maximum number of services to return per response."""
    page_token: builtins.str
    """Token to retrieve the next page of results. Omitted on the first request."""
    def __init__(
        self,
        *,
        resource_type: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "resource_type", b"resource_type"]) -> None: ...

global___ListServicesRequest = ListServicesRequest

@typing.final
class ListServicesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token to retrieve the next page of results."""
    @property
    def services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Service]:
        """List of services available for quota management."""

    def __init__(
        self,
        *,
        services: collections.abc.Iterable[global___Service] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "services", b"services"]) -> None: ...

global___ListServicesResponse = ListServicesResponse

@typing.final
class QuotaLimit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUOTA_ID_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    USAGE_FIELD_NUMBER: builtins.int
    quota_id: builtins.str
    """The unique id of the quota."""
    @property
    def limit(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """The limit value set for this quota."""

    @property
    def usage(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """The current usage level of this quota."""

    def __init__(
        self,
        *,
        quota_id: builtins.str = ...,
        limit: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        usage: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["limit", b"limit", "usage", b"usage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["limit", b"limit", "quota_id", b"quota_id", "usage", b"usage"]) -> None: ...

global___QuotaLimit = QuotaLimit

@typing.final
class Service(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """The unique id of the service."""
    name: builtins.str
    """The name of the service."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name"]) -> None: ...

global___Service = Service



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.serverless.functions.v1.network_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class NetworkServiceStub:
    """A set of methods for managing VPC networks connected to serverless resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    GetUsed: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.network_service_pb2.GetUsedNetworkRequest,
        yandex.cloud.serverless.functions.v1.network_service_pb2.UsedNetwork,
    ]
    """Returns the specified network used in serverless resources."""

    ListUsed: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.network_service_pb2.ListUsedNetworksRequest,
        yandex.cloud.serverless.functions.v1.network_service_pb2.ListUsedNetworksResponse,
    ]
    """Retrieves the list of networks in the specified scope that are used in serverless resources."""

    ListConnectedResources: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.network_service_pb2.ListConnectedResourcesRequest,
        yandex.cloud.serverless.functions.v1.network_service_pb2.ListConnectedResourcesResponse,
    ]
    """Retrieves the list of serverless resources connected to any network from the specified scope."""

    TriggerUsedCleanup: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.network_service_pb2.TriggerUsedNetworkCleanupRequest,
        yandex.cloud.serverless.functions.v1.network_service_pb2.TriggerUsedNetworkCleanupResponse,
    ]
    """Forces obsolete used network to start cleanup process as soon as possible.
    Invocation does not wait for start or end of the cleanup process.
    Second invocation with the same network does nothing until network is completely cleaned-up.
    """

class NetworkServiceAsyncStub:
    """A set of methods for managing VPC networks connected to serverless resources."""

    GetUsed: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.network_service_pb2.GetUsedNetworkRequest,
        yandex.cloud.serverless.functions.v1.network_service_pb2.UsedNetwork,
    ]
    """Returns the specified network used in serverless resources."""

    ListUsed: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.network_service_pb2.ListUsedNetworksRequest,
        yandex.cloud.serverless.functions.v1.network_service_pb2.ListUsedNetworksResponse,
    ]
    """Retrieves the list of networks in the specified scope that are used in serverless resources."""

    ListConnectedResources: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.network_service_pb2.ListConnectedResourcesRequest,
        yandex.cloud.serverless.functions.v1.network_service_pb2.ListConnectedResourcesResponse,
    ]
    """Retrieves the list of serverless resources connected to any network from the specified scope."""

    TriggerUsedCleanup: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.network_service_pb2.TriggerUsedNetworkCleanupRequest,
        yandex.cloud.serverless.functions.v1.network_service_pb2.TriggerUsedNetworkCleanupResponse,
    ]
    """Forces obsolete used network to start cleanup process as soon as possible.
    Invocation does not wait for start or end of the cleanup process.
    Second invocation with the same network does nothing until network is completely cleaned-up.
    """

class NetworkServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing VPC networks connected to serverless resources."""

    @abc.abstractmethod
    def GetUsed(
        self,
        request: yandex.cloud.serverless.functions.v1.network_service_pb2.GetUsedNetworkRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.functions.v1.network_service_pb2.UsedNetwork, collections.abc.Awaitable[yandex.cloud.serverless.functions.v1.network_service_pb2.UsedNetwork]]:
        """Returns the specified network used in serverless resources."""

    @abc.abstractmethod
    def ListUsed(
        self,
        request: yandex.cloud.serverless.functions.v1.network_service_pb2.ListUsedNetworksRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.functions.v1.network_service_pb2.ListUsedNetworksResponse, collections.abc.Awaitable[yandex.cloud.serverless.functions.v1.network_service_pb2.ListUsedNetworksResponse]]:
        """Retrieves the list of networks in the specified scope that are used in serverless resources."""

    @abc.abstractmethod
    def ListConnectedResources(
        self,
        request: yandex.cloud.serverless.functions.v1.network_service_pb2.ListConnectedResourcesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.functions.v1.network_service_pb2.ListConnectedResourcesResponse, collections.abc.Awaitable[yandex.cloud.serverless.functions.v1.network_service_pb2.ListConnectedResourcesResponse]]:
        """Retrieves the list of serverless resources connected to any network from the specified scope."""

    @abc.abstractmethod
    def TriggerUsedCleanup(
        self,
        request: yandex.cloud.serverless.functions.v1.network_service_pb2.TriggerUsedNetworkCleanupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.functions.v1.network_service_pb2.TriggerUsedNetworkCleanupResponse, collections.abc.Awaitable[yandex.cloud.serverless.functions.v1.network_service_pb2.TriggerUsedNetworkCleanupResponse]]:
        """Forces obsolete used network to start cleanup process as soon as possible.
        Invocation does not wait for start or end of the cleanup process.
        Second invocation with the same network does nothing until network is completely cleaned-up.
        """

def add_NetworkServiceServicer_to_server(servicer: NetworkServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/style_preset.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/style_preset.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/video/v1/style_preset.proto\x12\x15yandex.cloud.video.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\x9d\x06\n\x0bStylePreset\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x18\n\x10\x62\x61\x63kground_color\x18\x04 \x01(\t\x12!\n\x19widget_text_color_primary\x18\x05 \x01(\t\x12#\n\x1bwidget_text_color_secondary\x18\x06 \x01(\t\x12\x1b\n\x13widget_accent_color\x18\x07 \x01(\t\x12\x18\n\x10widget_block_gap\x18\x08 \x01(\x03\x12$\n\x1cwidget_block_separator_color\x18\t \x01(\t\x12\x1c\n\x14player_border_radius\x18\x0c \x01(\x03\x12\x14\n\x0cplayer_color\x18\r \x01(\t\x12/\n\'playlist_selected_item_background_color\x18\x0e \x01(\t\x12#\n\x1bplaylist_item_border_radius\x18\x0f \x01(\x03\x12\x19\n\x11playlist_item_gap\x18\x10 \x01(\x03\x12L\n\x11playlist_location\x18\x11 \x01(\x0e\x32\x31.yandex.cloud.video.v1.StylePreset.WidgetLocation\x12\x34\n\rright_widgets\x18\x14 \x03(\x0b\x32\x1d.yandex.cloud.video.v1.Widget\x12\x35\n\x0e\x62ottom_widgets\x18\x15 \x03(\x0b\x32\x1d.yandex.cloud.video.v1.Widget\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"H\n\x0eWidgetLocation\x12\x1f\n\x1bWIDGET_LOCATION_UNSPECIFIED\x10\x00\x12\t\n\x05RIGHT\x10\x01\x12\n\n\x06\x42OTTOM\x10\x02J\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0cJ\x04\x08\x12\x10\x14J\x04\x08\x16\x10\x64\"\xc0\x01\n\x06Widget\x12\x44\n\rsummarization\x18\x01 \x01(\x0b\x32+.yandex.cloud.video.v1.Widget.SummarizationH\x00\x12@\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32).yandex.cloud.video.v1.Widget.DescriptionH\x00\x1a\x0f\n\rSummarization\x1a\r\n\x0b\x44\x65scriptionB\x0e\n\x06widget\x12\x04\xc0\xc1\x31\x01\x42\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.style_preset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_WIDGET'].oneofs_by_name['widget']._loaded_options = None
  _globals['_WIDGET'].oneofs_by_name['widget']._serialized_options = b'\300\3011\001'
  _globals['_STYLEPRESET']._serialized_start=132
  _globals['_STYLEPRESET']._serialized_end=929
  _globals['_STYLEPRESET_WIDGETLOCATION']._serialized_start=833
  _globals['_STYLEPRESET_WIDGETLOCATION']._serialized_end=905
  _globals['_WIDGET']._serialized_start=932
  _globals['_WIDGET']._serialized_end=1124
  _globals['_WIDGET_SUMMARIZATION']._serialized_start=1078
  _globals['_WIDGET_SUMMARIZATION']._serialized_end=1093
  _globals['_WIDGET_DESCRIPTION']._serialized_start=1095
  _globals['_WIDGET_DESCRIPTION']._serialized_end=1108
# @@protoc_insertion_point(module_scope)
